@@ -1,7 +1,17 @@
 pair <- function(obj, data, method=NULL, mpower=2, verbose=1){
 		nm <- NULL
 		strataID <- unique(obj$strata)
-		reservoir <- NULL		
+		reservoir <- NULL	
+		
+		cl <- unlist(lapply(data, class))
+		anyF <- any(cl %in% c("character","factor"))
+		if(anyF){
+		  cat("\nTransforming factor/charater variable to numeric to calculate distance in pair matching...\n")
+		  idf <- which(cl %in% c("character","factor"))
+		  for(i in 1:length(idf)){
+		    data[,idf[i]] <- as.numeric(as.character(data[,i]))
+		  }
+		}
 		for(i in strataID){
 		 idx <- which(obj$strata==i)
 		 n <- length(idx)
@@ -28,10 +38,14 @@ pair <- function(obj, data, method=NULL, mpower=2, verbose=1){
             nm <- rbind(nm, c(colnames(mat1), rownames(mat1)))
 		   } else {
 		    for(k in 1:m){
-             mins <- apply(mat1, 2, function(x) min(x, na.rm=TRUE))
-			 min.c <- min(mins, na.rm=TRUE)
-			 col <- which.min(mins)
-			 row <- which(mat1[,col]==min.c)[1]
+     #        mins <- apply(mat1, 2, function(x) min(x, na.rm=TRUE))
+		#	 min.c <- min(mins, na.rm=TRUE)
+		#      col <- which.min(mins)
+		#      row <- which(mat1[,col]==min.c)[1]
+		   if(all(is.na(mat1))) break ;
+			 idxMin <- which(mat1 == min(mat1,na.rm=TRUE), arr.ind = TRUE)
+			 col <- idxMin[1,"col"]
+			 row <- idxMin[1,"row"]
 			 mat1[row, 1:m] <- NA
 			 mat1[1:m ,col] <- NA
 			 nm <- rbind(nm, c(colnames(mat1)[col], rownames(mat1)[row])) 
@@ -70,10 +84,14 @@ pair <- function(obj, data, method=NULL, mpower=2, verbose=1){
             nm2 <- rbind(nm2, c(colnames(mat1), rownames(mat1)))
 		   } else {
 		    for(k in 1:m){
-             mins <- apply(mat1, 2, function(x) min(x, na.rm=TRUE))
-			 min.c <- min(mins, na.rm=TRUE)
-			 col <- which.min(mins)
-			 row <- which(mat1[,col]==min.c)[1]
+#              mins <- apply(mat1, 2, function(x) min(x, na.rm=TRUE))
+# 			 min.c <- min(mins, na.rm=TRUE)
+# 			 col <- which.min(mins)
+# 			 row <- which(mat1[,col]==min.c)[1]
+			 if(all(is.na(mat1))) break ;
+			 idxMin <- which(mat1 == min(mat1,na.rm=TRUE), arr.ind = TRUE)
+			 col <- idxMin[1,"col"]
+			 row <- idxMin[1,"row"]
 			 mat1[row, 1:m] <- NA
 			 mat1[1:m ,col] <- NA
 			 nm2 <- rbind(nm2, c(colnames(mat1)[col], rownames(mat1)[row])) 
